==> zio-aws-iottwinmaker_2.13-5.17.128.1-sources.jar: zio/aws/iottwinmaker/model/ComponentResponse.scala <==
package zio.aws.iottwinmaker.model
import zio.aws.iottwinmaker.model.primitives.{
  Description,
  ComponentTypeId,
  Name
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ComponentResponse(
    componentName: Option[Name] = None,
    componentTypeId: Option[ComponentTypeId] = None,
    definedIn: Option[String] = None,
    description: Option[Description] = None,
    properties: Option[Map[Name, zio.aws.iottwinmaker.model.PropertyResponse]] =
      None,
    status: Option[zio.aws.iottwinmaker.model.Status] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse = {
    import ComponentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse
      .builder()
      .optionallyWith(
        componentName.map(value => Name.unwrap(value): java.lang.String)
      )(_.componentName)
      .optionallyWith(
        componentTypeId.map(value =>
          ComponentTypeId.unwrap(value): java.lang.String
        )
      )(_.componentTypeId)
      .optionallyWith(definedIn.map(value => value: java.lang.String))(
        _.definedIn
      )
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        properties.map(value =>
          value
            .map({ case (key, value) =>
              (Name.unwrap(key): java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.properties)
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .build()
  }
  def asReadOnly: zio.aws.iottwinmaker.model.ComponentResponse.ReadOnly =
    zio.aws.iottwinmaker.model.ComponentResponse.wrap(buildAwsValue())
}
object ComponentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.ComponentResponse =
      zio.aws.iottwinmaker.model.ComponentResponse(
        componentName.map(value => value),
        componentTypeId.map(value => value),
        definedIn.map(value => value),
        description.map(value => value),
        properties.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        status.map(value => value.asEditable)
      )
    def componentName: Option[Name]
    def componentTypeId: Option[ComponentTypeId]
    def definedIn: Option[String]
    def description: Option[Description]
    def properties: Option[
      Map[Name, zio.aws.iottwinmaker.model.PropertyResponse.ReadOnly]
    ]
    def status: Option[zio.aws.iottwinmaker.model.Status.ReadOnly]
    def getComponentName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("componentName", componentName)
    def getComponentTypeId: ZIO[Any, AwsError, ComponentTypeId] =
      AwsError.unwrapOptionField("componentTypeId", componentTypeId)
    def getDefinedIn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("definedIn", definedIn)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getProperties: ZIO[Any, AwsError, Map[
      Name,
      zio.aws.iottwinmaker.model.PropertyResponse.ReadOnly
    ]] = AwsError.unwrapOptionField("properties", properties)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.iottwinmaker.model.Status.ReadOnly] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse
  ) extends zio.aws.iottwinmaker.model.ComponentResponse.ReadOnly {
    override val componentName: Option[Name] = scala
      .Option(impl.componentName())
      .map(value => zio.aws.iottwinmaker.model.primitives.Name(value))
    override val componentTypeId: Option[ComponentTypeId] = scala
      .Option(impl.componentTypeId())
      .map(value =>
        zio.aws.iottwinmaker.model.primitives.ComponentTypeId(value)
      )
    override val definedIn: Option[String] =
      scala.Option(impl.definedIn()).map(value => value: String)
    override val description: Option[Description] = scala
      .Option(impl.description())
      .map(value => zio.aws.iottwinmaker.model.primitives.Description(value))
    override val properties: Option[
      Map[Name, zio.aws.iottwinmaker.model.PropertyResponse.ReadOnly]
    ] = scala
      .Option(impl.properties())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.iottwinmaker.model.primitives.Name(
              key
            ) -> zio.aws.iottwinmaker.model.PropertyResponse.wrap(value)
          })
          .toMap
      )
    override val status: Option[zio.aws.iottwinmaker.model.Status.ReadOnly] =
      scala
        .Option(impl.status())
        .map(value => zio.aws.iottwinmaker.model.Status.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse
  ): zio.aws.iottwinmaker.model.ComponentResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iottwinmaker_2.13-5.17.202.1-sources.jar: zio/aws/iottwinmaker/model/ComponentResponse.scala <==
package zio.aws.iottwinmaker.model
import zio.aws.iottwinmaker.model.primitives.{
  Description,
  ComponentTypeId,
  Name
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ComponentResponse(
    componentName: Optional[Name] = Optional.Absent,
    componentTypeId: Optional[ComponentTypeId] = Optional.Absent,
    definedIn: Optional[String] = Optional.Absent,
    description: Optional[Description] = Optional.Absent,
    properties: Optional[
      Map[Name, zio.aws.iottwinmaker.model.PropertyResponse]
    ] = Optional.Absent,
    status: Optional[zio.aws.iottwinmaker.model.Status] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse = {
    import ComponentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse
      .builder()
      .optionallyWith(
        componentName.map(value => Name.unwrap(value): java.lang.String)
      )(_.componentName)
      .optionallyWith(
        componentTypeId.map(value =>
          ComponentTypeId.unwrap(value): java.lang.String
        )
      )(_.componentTypeId)
      .optionallyWith(definedIn.map(value => value: java.lang.String))(
        _.definedIn
      )
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        properties.map(value =>
          value
            .map({ case (key, value) =>
              (Name.unwrap(key): java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.properties)
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .build()
  }
  def asReadOnly: zio.aws.iottwinmaker.model.ComponentResponse.ReadOnly =
    zio.aws.iottwinmaker.model.ComponentResponse.wrap(buildAwsValue())
}
object ComponentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.ComponentResponse =
      zio.aws.iottwinmaker.model.ComponentResponse(
        componentName.map(value => value),
        componentTypeId.map(value => value),
        definedIn.map(value => value),
        description.map(value => value),
        properties.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        status.map(value => value.asEditable)
      )
    def componentName: Optional[Name]
    def componentTypeId: Optional[ComponentTypeId]
    def definedIn: Optional[String]
    def description: Optional[Description]
    def properties: Optional[
      Map[Name, zio.aws.iottwinmaker.model.PropertyResponse.ReadOnly]
    ]
    def status: Optional[zio.aws.iottwinmaker.model.Status.ReadOnly]
    def getComponentName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("componentName", componentName)
    def getComponentTypeId: ZIO[Any, AwsError, ComponentTypeId] =
      AwsError.unwrapOptionField("componentTypeId", componentTypeId)
    def getDefinedIn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("definedIn", definedIn)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getProperties: ZIO[Any, AwsError, Map[
      Name,
      zio.aws.iottwinmaker.model.PropertyResponse.ReadOnly
    ]] = AwsError.unwrapOptionField("properties", properties)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.iottwinmaker.model.Status.ReadOnly] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse
  ) extends zio.aws.iottwinmaker.model.ComponentResponse.ReadOnly {
    override val componentName: Optional[Name] = zio.aws.core.internal
      .optionalFromNullable(impl.componentName())
      .map(value => zio.aws.iottwinmaker.model.primitives.Name(value))
    override val componentTypeId: Optional[ComponentTypeId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.componentTypeId())
        .map(value =>
          zio.aws.iottwinmaker.model.primitives.ComponentTypeId(value)
        )
    override val definedIn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.definedIn())
      .map(value => value: String)
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iottwinmaker.model.primitives.Description(value))
    override val properties: Optional[
      Map[Name, zio.aws.iottwinmaker.model.PropertyResponse.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.properties())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.iottwinmaker.model.primitives.Name(
              key
            ) -> zio.aws.iottwinmaker.model.PropertyResponse.wrap(value)
          })
          .toMap
      )
    override val status: Optional[zio.aws.iottwinmaker.model.Status.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.iottwinmaker.model.Status.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ComponentResponse
  ): zio.aws.iottwinmaker.model.ComponentResponse.ReadOnly = new Wrapper(impl)
}
